@@ -15,7 +15,7 @@ from shpc.logger import logger
 
 try:
     from ruamel_yaml import YAML
-except:
+except ImportError:
     from ruamel.yaml import YAML
 
 
